@@ -58,7 +58,7 @@
 #' @source From the CIA World Factbook,
 #' \url{https://www.cia.gov/library/publications/the-world-factbook/}
 #' @seealso \code{\link[mosaic]{CIAdata}}
-#' @references \url{https://github.com/factbook/factbook.csv}
+#' @references \url{https://github.com/factbook/factbook/blob/master/data/categories.csv}
 #' @keywords datasets
 #' @examples
 #' 
@@ -109,10 +109,6 @@
 #' with(Cherry, table(table(name.yob)))
 "Cherry"
 
-#' Cancer
-#' @docType data
-"Cancer"
-
 #' NYC Restaurant Health Violations
 #' @docType data
 #' @format{
@@ -435,4 +431,34 @@
 #' @rdname CholeraDeaths
 #' @format An object of class \code{\link[sp]{SpatialPointsDataFrame}}.
 #' @docType data
-"CholeraPumps"
\ No newline at end of file
+"CholeraPumps"
+
+#' Gene expression in cancer
+#' 
+#' The data come from a National Cancer Institute study of gene expression in
+#' cell lines drawn from various sorts of cancer.
+#' 
+#' The expression data, \code{NCI60} is a dataframe of 41,078 gene probes (rows)
+#' and 60 cell lines (columns).  The first column, \code{Probe} gives the name
+#' of the Agilent microarray probe.  Each of the remaining columns is named for
+#' a cell line.  The value is the log-2 expression associated with that probe
+#' for the cell line.
+#' 
+#' \code{\link{Cancer}} gives information about each cell line.
+#' 
+#' @docType data
+#' @format See the description
+#' @seealso \code{\link{Cancer}}
+#' @references Staunton et al. (\url{http://www.pnas.org/content/98/19/10787.full})
+#' 
+#' D.T. Ross et al. (2000) Nature Genetics, 24(3):227-234
+#' (\url{http://discover.nci.nih.gov/host/2000_systematic_abstract.jsp})
+#' @examples
+#' 
+#' data(NCI60_tiny) 
+#' 
+"NCI60_tiny"
+
+#' @rdname NCI60_tiny
+#' @docType data
+"Cancer"
